@@ -30,7 +30,8 @@ USA.
 
 /*GtkWidget *setup_body (GtkWidget *);*/
 GtkWidget *setup_body (trans_gui *);
-void transtype (gpointer);
+/*void transtype (gpointer); */
+void transtype (GtkWidget *, gpointer);
 short transtype_int (void);
 
 /*extern trans_win *microstrip_win (GtkWidget *);*/
