@@ -34,6 +34,29 @@
 #include "c_microstrip.h"
 
 
+/* the following definitions are just a quick hack for mingw32 */
+#ifndef HAVE_ATANH
+static double atanh(double x)
+{
+  return (0.5 * log((1.0 + x) / (1.0 - x)));
+}
+#endif
+
+#ifndef HAVE_ASINH
+static double asinh(double x)
+{
+  return log(x + sqrt(x * x + 1.0));
+}
+#endif
+
+#ifndef HAVE_ACOSH
+static double acosh(double x)
+{
+  return log(x + sqrt(x * x - 1.0));
+}
+#endif
+
+
 static microstrip *aux_ms = NULL;
 
 /*
@@ -53,8 +76,83 @@ static gfloat skin_depth(c_microstrip * c_ms)
   return depth;
 }
 
+/**
+ * delta_u_thickness_single - compute the thickness effect on normalized width for a single microstrip line 
+ * @u: normalized width
+ * @t_h: normalized thickness
+ *
+ * delta_u_thickness_single() computes the thickness effect on normalized width for a single microstrip line
+ *
+ * References: 
+ * H. A. Atwater, "Simplified Design Equations for Microstrip Line Parameters", Microwave Journal, pp. 109-115, November 1989.
+ */
+gfloat delta_u_thickness_single(gfloat u, gfloat t_h)
+{
+  gfloat delta_u;
 
-/* compute various parameters for a single line */
+  if (t_h > 0.0) {
+    delta_u = (1.25 * t_h / M_PI) * (1.0 + log((2.0 + (4.0 * M_PI * u - 2.0) / (1.0 + exp(-100.0 * (u - 1.0 / (2.0 * M_PI))))) / t_h));
+  } else {
+    delta_u = 0.0;
+  }
+
+  /* fprintf(stderr, "delta_u_thickness_single = %e\n", delta_u); */
+
+  return delta_u;
+}
+
+/**
+ * delta_u_thickness - compute the thickness effect on normalized width
+ * @c_ms: coupled microstrips structure pointer
+ *
+ * compute the thickness effect on normalized width for coupled microstrips
+ *
+ * References: Rolf Jansen, "High-Speed Cmputation of Single and Coupled Microstrip Parameters Including Dispersion, High-Order Modes, Loss and Finite Strip Thickness", IEEE Trans. MTT, vol. 26, no. 2, pp. 75-82, Feb. 1978
+ *
+ */
+static void delta_u_thickness(c_microstrip * c_ms)
+{
+  gfloat e_r, s, h, w, t, u, g, t_h;
+  gfloat delta_u, delta_t, delta_u_e, delta_u_o;
+
+  e_r = c_ms->er;
+  s = c_ms->s;
+  h = c_ms->h;
+  w = c_ms->w;
+  t = c_ms->t;
+  u = w / h;			/* normalized line width */
+  g = s / h;			/* normalized line spacing */
+  t_h = t / h;			/* normalized strip thickness */
+
+  if (t_h > 0.0) {
+    /* single microstrip correction for finite strip thickness */
+    delta_u = delta_u_thickness_single(u, t_h);
+    delta_t = t_h / (g * e_r);
+    /* thickness correction for the even- and odd-mode */
+    delta_u_e = delta_u * (1.0 - 0.5 * exp(-0.69 * delta_u / delta_t));
+    delta_u_o = delta_u_e + delta_t;
+  } else {
+    delta_u_e = delta_u_o = 0.0;
+  }
+
+  c_ms->w_t_e = w + delta_u_e * h;
+  c_ms->w_t_o = w + delta_u_o * h;
+
+  /* fprintf(stderr, "w_t_e = %e\n", c_ms->w_t_e); */
+  /* fprintf(stderr, "w_t_o = %e\n", c_ms->w_t_o); */
+}
+
+
+/**
+ * compute_single_line() - compute various parameters for a single line
+ * @c_ms: coupled microstrips structure pointer
+ *
+ * compute various parameters for a zero-thickness single microstrip line with geometrical dimensions taken from the coupled microstrips structure pointed by @c_ms.
+ *
+ * References: Manfred Kirschning and Rolf Jansen, "Accurate Wide-Range Design Equations for the Frequency-Dependent Characteristic of Parallel Coupled Microstrip Lines", IEEE Trans. MTT, vol. 32, no. 1, Jan. 1984
+ *
+ * E. Hammerstad and O. Jensen, "Accurate Models for Microstrip Computer-Aided Design", IEEE MTT-S Symposium Digest, pp. 407-409, Jun. 1980
+ */
 static void compute_single_line(c_microstrip * c_ms)
 {
   gfloat er, mur, h, w, s, ht, t;
@@ -91,15 +189,100 @@ static void compute_single_line(c_microstrip * c_ms)
   er_eff_single = aux_ms->er_eff_0;
   Z0_single = aux_ms->Z0_0;
 
-  //fprintf(stderr, "aux_ms->C = %e\n", sqrt(aux_ms->er_eff_0) / (C * aux_ms->Z0_0));
+  //fprintf(stderr, "aux_ms->C = %e\n", sqrt(aux_ms->er_eff_0) / (C0 * aux_ms->Z0_0));
 }
 
 
-/* er_eff_static() - compute the static effective dielectric constants */
+/**
+ * filling_factor_even() - compute the filling factor for the coupled microstrips even-mode without cover and zero conductor thickness 
+ * @u: normalized width
+ * @g: normalized strips spacing
+ * @e_r: relative dielectric constant
+ */
+gfloat filling_factor_even(gfloat u, gfloat g, gfloat e_r)
+{
+  gfloat v, v3, v4, a_e, b_e, q_inf;
+
+  v = u * (20.0 + g * g) / (10.0 + g * g) + g * exp(-g);
+  v3 = v * v * v;
+  v4 = v3 * v;
+  a_e = 1.0 + log((v4 + v * v / 2704.0) / (v4 + 0.432)) / 49.0 + log(1.0 + v3 / 5929.741)
+    / 18.7;
+  b_e = 0.564 * pow(((e_r - 0.9) / (e_r + 3.0)), 0.053);
+
+  /* filling factor, with width corrected for thickness */
+  q_inf = pow((1.0 + 10.0 / v), -a_e * b_e);
+
+  return q_inf;
+}
+
+/**
+ * filling_factor_odd() - compute the filling factor for the coupled microstrips odd-mode without cover and zero conductor thickness 
+ * @u: normalized width
+ * @g: normalized strips spacing
+ * @e_r: relative dielectric constant
+ */
+gfloat filling_factor_odd(gfloat u, gfloat g, gfloat e_r)
+{
+  gfloat b_o, c_o, d_o, q_inf;
+
+  b_o = 0.747 * e_r / (0.15 + e_r);
+  c_o = b_o - (b_o - 0.207) * exp(-0.414 * u);
+  d_o = 0.593 + 0.694 * exp(-0.562 * u);
+
+  /* filling factor, with width corrected for thickness */
+  q_inf = exp(-c_o * pow(g, d_o));
+
+  return q_inf;
+}
+
+
+/**
+ * delta_q_cover_even() - compute the cover effect on filling factor for the even-mode 
+ * @h2h: normalized cover height
+ */
+gfloat delta_q_cover_even(gfloat h2h)
+{
+  gfloat q_c;
+
+  if (h2h <= 39) {
+    q_c = tanh(1.626 + 0.107 * h2h - 1.733 / sqrt(h2h));
+  } else {
+    q_c = 1.0;
+  }
+
+  return q_c;
+}
+
+/**
+ * delta_q_cover_odd() - compute the cover effect on filling factor for the odd-mode 
+ * @h2h: normalized cover height
+ */
+gfloat delta_q_cover_odd(gfloat h2h)
+{
+  gfloat q_c;
+
+  if (h2h <= 7) {
+    q_c = tanh(9.575 / (7.0 - h2h) - 2.965 + 1.68 * h2h - 0.311 * h2h * h2h);
+  } else {
+    q_c = 1.0;
+  }
+
+  return q_c;
+}
+
+
+/**
+ * er_eff_static() - compute the static effective dielectric constants 
+ * @c_ms: coupled microstrips structure pointer
+ *
+ * compute the static effective dielectric constants of the coupled microstrips structure pointed by @c_ms. 
+ * References: Manfred Kirschning and Rolf Jansen, "Accurate Wide-Range Design Equations for the Frequency-Dependent Characteristic of Parallel Coupled Microstrip Lines", IEEE Trans. MTT, vol. 32, no. 1, Jan. 1984
+ */
 static void er_eff_static(c_microstrip * c_ms)
 {
-  gfloat er, s, h, w, u, g;
-  gfloat v, v3, v4, a_e, b_e, a_o, b_o, c_o, d_o;
+  gfloat er, s, h, w_t_e, w_t_o, u_t_e, u_t_o, g, h2, h2h;
+  gfloat a_o, t, t_h, q, q_c, q_t, q_inf;
   gfloat er_eff_single;
 
   /* compute zero-thickness single line parameters */
@@ -109,69 +292,182 @@ static void er_eff_static(c_microstrip * c_ms)
   er = c_ms->er;
   s = c_ms->s;
   h = c_ms->h;
-  w = c_ms->w;
-  u = w / h;			/* normalize line width */
-  g = s / h;			/* normalize line spacing */
+  w_t_e = c_ms->w_t_e;
+  w_t_o = c_ms->w_t_o;
+  t = c_ms->t;
+  h2 = c_ms->ht;
+  u_t_e = w_t_e / h;		/* normalized even_mode line width */
+  u_t_o = w_t_o / h;		/* normalized odd_mode line width */
+  g = s / h;			/* normalized line spacing */
+  h2h = h2 / h;			/* normalized cover height */
+  t_h = t / h;			/* normalized strip thickness */
 
-  v = u * (20.0 + g * g) / (10.0 + g * g) + g * exp(-g);
-  v3 = v * v * v;
-  v4 = v3 * v;
-  a_e = 1.0 + log((v4 + v * v / 2704.0) / (v4 + 0.432)) / 49.0 + log(1.0 + v3 / 5929.741)
-    / 18.7;
-  b_e = 0.564 * pow(((er - 0.9) / (er + 3.0)), 0.053);
+  /* filling factor, computed with thickness corrected width */
+  q_inf = filling_factor_even(u_t_e, g, er);
+  /* cover effect */
+  q_c = delta_q_cover_even(h2h);
+  /* thickness effect */
+  q_t = delta_q_thickness(u_t_e, t_h);
+  /* resultant filling factor */
+  q = (q_inf - q_t) * q_c;
   /* static even-mode effective dielectric constant */
-  c_ms->er_eff_e_0 = 0.5 * (er + 1.0) + 0.5 * (er - 1.0) * pow((1.0 + 10.0 / v), -a_e * b_e);
+  c_ms->er_eff_e_0 = 0.5 * (er + 1.0) + 0.5 * (er - 1.0) * q;
+
+  /* filling factor, with width corrected for thickness */
+  q_inf = filling_factor_odd(u_t_o, g, er);
+  /* cover effect */
+  q_c = delta_q_cover_odd(h2h);
+  /* thickness effect */
+  q_t = delta_q_thickness(u_t_o, t_h);
+  /* resultant filling factor */
+  q = (q_inf - q_t) * q_c;
+
+  a_o = 0.7287 * (er_eff_single - 0.5 * (er + 1.0)) * (1.0 - exp(-0.179 * u_t_o));
 
-  a_o = 0.7287 * (er_eff_single - 0.5 * (er + 1.0)) * (1.0 - exp(-0.179 * u));
-  b_o = 0.747 * er / (0.15 + er);
-  c_o = b_o - (b_o - 0.207) * exp(-0.414 * u);
-  d_o = 0.593 + 0.694 * exp(-0.562 * u);
   /* static odd-mode effective dielectric constant */
-  c_ms->er_eff_o_0 = (0.5 * (er + 1.0) + a_o - er_eff_single) * exp(-c_o * pow(g, d_o)) + er_eff_single;
+  c_ms->er_eff_o_0 = (0.5 * (er + 1.0) + a_o - er_eff_single) * q + er_eff_single;
 }
 
 
-/* Z0_even_odd() - compute the static even- and odd-mode impedances */
+/**
+ * delta_Z0_even_cover() - compute the even-mode impedance correction for a homogeneous microstrip due to the cover
+ * @g: normalized strips spacing
+ * @u: normalized width
+ * @h2h: normalized cover height
+ *
+ * compute the even-mode impedance correction for a homogeneous microstrip due to the cover
+ *
+ * References:
+ * S. March, "Microstrip Packaging: Watch the Last Step", Microwaves, vol. 20, no. 13, pp. 83.94, Dec. 1981.
+ */
+static gfloat delta_Z0_even_cover(gfloat g, gfloat u, gfloat h2h)
+{
+  gfloat f_e, g_e, delta_Z0_even;
+  gfloat x, y, A, B, C, D, E, F;
+
+  A = -4.351 / pow(1.0 + h2h, 1.842);
+  B = 6.639 / pow(1.0 + h2h, 1.861);
+  C = -2.291 / pow(1.0 + h2h, 1.90);
+  f_e = 1.0 - atanh(A + (B + C * u) * u);
+
+  x = pow(10.0, 0.103 * g - 0.159);
+  y = pow(10.0, 0.0492 * g - 0.073);
+  D = 0.747 / sin(0.5 * M_PI * x);
+  E = 0.725 * sin(0.5 * M_PI * y);
+  F = pow(10.0, 0.11 - 0.0947 * g);
+  g_e = 270.0 * (1.0 - tanh(D + E * sqrt(1.0 + h2h) - F / (1.0 + h2h)));
+
+  delta_Z0_even = f_e * g_e;
+
+  return delta_Z0_even;
+}
+
+
+/**
+ * delta_Z0_odd_cover() - compute the odd-mode impedance correction for a homogeneous microstrip due to the cover
+ * @g: normalized strips spacing
+ * @u: normalized width
+ * @h2h: normalized cover height
+ *
+ * compute the odd-mode impedance correction for a homogeneous microstrip due to the cover
+ *
+ * References:
+ * S. March, "Microstrip Packaging: Watch the Last Step", Microwaves, vol. 20, no. 13, pp. 83.94, Dec. 1981.
+ */
+static gfloat delta_Z0_odd_cover(gfloat g, gfloat u, gfloat h2h)
+{
+  gfloat f_o, g_o, delta_Z0_odd;
+  gfloat G, J, K, L;
+
+  J = tanh(pow(1.0 + h2h, 1.585) / 6.0);
+  f_o = pow(u, J);
+
+  G = 2.178 - 0.796 * g;
+  if (g > 0.858) {
+    K = log10(20.492 * pow(g, 0.174));
+  } else {
+    K = 1.30;
+  }
+  if (g > 0.873) {
+    L = 2.51 * pow(g, -0.462);
+  } else {
+    L = 2.674;
+  }
+  g_o = 270.0 * (1.0 - tanh(G + K * sqrt(1.0 + h2h) - L / (1.0 + h2h)));
+
+  delta_Z0_odd = f_o * g_o;
+
+  return delta_Z0_odd;
+}
+
+/**
+ * Z0_even_odd() - compute the static even- and odd-mode static impedances 
+ * @c_ms: coupled microstrips structure pointer
+ *
+ * compute the static even- and odd-mode static impedances 
+ *
+ * References: Manfred Kirschning and Rolf Jansen, "Accurate Wide-Range Design Equations for the Frequency-Dependent Characteristic of Parallel Coupled Microstrip Lines", IEEE Trans. MTT, vol. 32, no. 1, Jan. 1984
+ *
+ */
 static void Z0_even_odd(c_microstrip * c_ms)
 {
-  gfloat er_eff, s, h, w, u, g;
+  gfloat er_eff, s, h, h2, w_t_e, w_t_o, u_t_e, u_t_o, g, h2h;
   gfloat Q_1, Q_2, Q_3, Q_4, Q_5, Q_6, Q_7, Q_8, Q_9, Q_10;
-  gfloat Z0_single, er_eff_single;
+  gfloat Z0_e_0, delta_Z0_e_0, Z0_o_0, delta_Z0_o_0, Z0_single, er_eff_single;
 
   s = c_ms->s;
   h = c_ms->h;
-  w = c_ms->w;
-  u = w / h;			/* normalize line width */
-  g = s / h;			/* normalize line spacing */
+  h2 = c_ms->ht;
+  w_t_e = c_ms->w_t_e;
+  w_t_o = c_ms->w_t_o;
+  u_t_e = w_t_e / h;		/* normalized even-mode line width */
+  u_t_o = w_t_o / h;		/* normalized odd-mode line width */
+  g = s / h;			/* normalized line spacing */
+  h2h = h2 / h;			/* normalized cover height */
 
   Z0_single = aux_ms->Z0_0;
   er_eff_single = aux_ms->er_eff_0;
 
+  /* even-mode */
   er_eff = c_ms->er_eff_e_0;
-  Q_1 = 0.8695 * pow(u, 0.194);
+  Q_1 = 0.8695 * pow(u_t_e, 0.194);
   Q_2 = 1.0 + 0.7519 * g + 0.189 * pow(g, 2.31);
   Q_3 = 0.1975 + pow((16.6 + pow((8.4 / g), 6.0)), -0.387) + log(pow(g, 10.0) / (1.0 + pow(g / 3.4, 10.0))) / 241.0;
-  Q_4 = 2.0 * Q_1 / (Q_2 * (exp(-g) * pow(u, Q_3) + (2.0 - exp(-g)) * pow(u, -Q_3)));
+  Q_4 = 2.0 * Q_1 / (Q_2 * (exp(-g) * pow(u_t_e, Q_3) + (2.0 - exp(-g)) * pow(u_t_e, -Q_3)));
   /* static even-mode impedance */
-  c_ms->Z0_e_0 = Z0_single * sqrt(er_eff_single / er_eff) / (1.0 - sqrt(er_eff_single) * Q_4 * Z0_single / 377.0);
+  Z0_e_0 = Z0_single * sqrt(er_eff_single / er_eff) / (1.0 - sqrt(er_eff_single) * Q_4 * Z0_single / 377.0);
+  /* correction for cover */
+  delta_Z0_e_0 = delta_Z0_even_cover(g, u_t_e, h2h) / sqrt(er_eff);
 
+  c_ms->Z0_e_0 = Z0_e_0 - delta_Z0_e_0;
+
+  /* odd-mode */
   er_eff = c_ms->er_eff_o_0;
   Q_5 = 1.794 + 1.14 * log(1.0 + 0.638 / (g + 0.517 * pow(g, 2.43)));
   Q_6 = 0.2305 + log(pow(g, 10.0) / (1.0 + pow(g / 5.8, 10.0))) / 281.3 + log(1.0 + 0.598 * pow(g, 1.154)) / 5.1;
   Q_7 = (10.0 + 190.0 * g * g) / (1.0 + 82.3 * g * g * g);
   Q_8 = exp(-6.5 - 0.95 * log(g) - pow(g / 0.15, 5.0));
   Q_9 = log(Q_7) * (Q_8 + 1.0 / 16.5);
-  Q_10 = (Q_2 * Q_4 - Q_5 * exp(log(u) * Q_6 * pow(u, -Q_9))) / Q_2;
+  Q_10 = (Q_2 * Q_4 - Q_5 * exp(log(u_t_o) * Q_6 * pow(u_t_o, -Q_9))) / Q_2;
 
   /* static odd-mode impedance */
-  c_ms->Z0_o_0 = Z0_single * sqrt(er_eff_single / er_eff) / (1.0 - sqrt(er_eff_single) * Q_10 * Z0_single / 377.0);
+  Z0_o_0 = Z0_single * sqrt(er_eff_single / er_eff) / (1.0 - sqrt(er_eff_single) * Q_10 * Z0_single / 377.0);
+  /* correction for cover */
+  delta_Z0_o_0 = delta_Z0_odd_cover(g, u_t_o, h2h) / sqrt(er_eff);
 
+  c_ms->Z0_o_0 = Z0_o_0 - delta_Z0_o_0;
 
   //fprintf(stderr, "Z0e = %e\n", c_ms->Z0e);
   //fprintf(stderr, "Z0o = %e\n", c_ms->Z0o);
 }
 
-/* mur_eff() - returns effective magnetic permeability */
+/**
+ * mur_eff() - returns effective magnetic permeability 
+ * @c_ms: coupled microstrips structure pointer
+ *
+ * CURRENTLY NOT SUPPORTED !
+ *
+ **/
 static gfloat mur_eff(c_microstrip * c_ms)
 {
   gfloat mureff;
@@ -182,7 +478,15 @@ static gfloat mur_eff(c_microstrip * c_ms)
 }
 
 
-/* er_eff_freq() - compute er_eff as a function of frequency */
+/**
+ * er_eff_freq() - compute er_eff as a function of frequency 
+ * @c_ms: coupled microstrips structure pointer
+ *
+ * compute the effective relative dielectric permettivity as a function of frequency 
+ *
+ * References: Manfred Kirschning and Rolf Jansen, "Accurate Wide-Range Design Equations for the Frequency-Dependent Characteristic of Parallel Coupled Microstrip Lines", IEEE Trans. MTT, vol. 32, no. 1, Jan. 1984
+ *
+ */
 static void er_eff_freq(c_microstrip * c_ms)
 {
   gfloat P_1, P_2, P_3, P_4, P_5, P_6, P_7;
@@ -229,7 +533,16 @@ static void er_eff_freq(c_microstrip * c_ms)
   c_ms->er_eff_o = er - (er - er_eff) / (1.0 + F_o);
 }
 
-/* conductor_losses() - compute microstrips conductor losses per unit length */
+
+/**
+ * conductor_losses() - compute microstrips conductor losses per unit length 
+ * @c_ms: coupled microstrips structure pointer
+ *
+ * compute microstrips conductor losses per unit length 
+ *
+ * References: E. Hammerstad and O. Jensen, "Accurate Models for Microstrip Computer-Aided Design", IEEE MTT-S Symposium Digest, pp. 407-409, Jun. 1980
+ *
+ */
 static void conductor_losses(c_microstrip * c_ms)
 {
   gfloat f, w, e_r_eff_e_0, e_r_eff_o_0, Z0_h_e, Z0_h_o, delta, sigma, rough, tand;
@@ -253,26 +566,34 @@ static void conductor_losses(c_microstrip * c_ms)
     R_s = 1.0 / (sigma * delta);
     /* correction for surface roughness */
     R_s *= 1.0 + ((2.0 / M_PI) * atan(1.40 * pow((rough / delta), 2.0)));
-    
+
     /* even-mode strip inductive quality factor */
-    Q_c_e = (M_PI * Z0_h_e * w * f) / (R_s * C * K);
+    Q_c_e = (M_PI * Z0_h_e * w * f) / (R_s * C0 * K);
     /* even-mode losses per unith length */
-    alpha_c_e = (20.0 * M_PI / log(10.0)) * f * sqrt(e_r_eff_e_0) / (C * Q_c_e);
-    
-  /* odd-mode strip inductive quality factor */
-    Q_c_o = (M_PI * Z0_h_o * w * f) / (R_s * C * K);
+    alpha_c_e = (20.0 * M_PI / log(10.0)) * f * sqrt(e_r_eff_e_0) / (C0 * Q_c_e);
+
+    /* odd-mode strip inductive quality factor */
+    Q_c_o = (M_PI * Z0_h_o * w * f) / (R_s * C0 * K);
     /* odd-mode losses per unith length */
-    alpha_c_o = (20.0 * M_PI / log(10.0)) * f * sqrt(e_r_eff_o_0) / (C * Q_c_o);
+    alpha_c_o = (20.0 * M_PI / log(10.0)) * f * sqrt(e_r_eff_o_0) / (C0 * Q_c_o);
   } else {
     alpha_c_e = alpha_c_o = 0.0;
   }
-  
+
   c_ms->atten_cond_e = alpha_c_e * c_ms->l;
   c_ms->atten_cond_o = alpha_c_o * c_ms->l;
 }
 
 
-/* dielectric_losses() - compute microstrips dielectric losses per unit length */
+/** 
+ * dielectric_losses() - compute microstrips dielectric losses per unit length
+ * @c_ms: coupled microstrips structure pointer
+ *
+ * compute microstrips dielectric losses per unit length
+ *
+ * References: E. J. Denlinger, "Losses of microstrip lines", , IEEE Trans. MTT, vol. 28, no. 6, pp. 513-522, Jun. 1980
+ *
+ */
 static void dielectric_losses(c_microstrip * c_ms)
 {
   gfloat f, e_r, e_r_eff_e_0, e_r_eff_o_0, tand;
@@ -284,15 +605,19 @@ static void dielectric_losses(c_microstrip * c_ms)
   e_r_eff_o_0 = c_ms->er_eff_o_0;
   tand = c_ms->tand;
 
-  alpha_d_e = (20.0 * M_PI / log(10.0)) * (f / C) * (e_r / sqrt(e_r_eff_e_0)) * ((e_r_eff_e_0 - 1.0) / (e_r - 1.0)) * tand;
-  alpha_d_o = (20.0 * M_PI / log(10.0)) * (f / C) * (e_r / sqrt(e_r_eff_o_0)) * ((e_r_eff_o_0 - 1.0) / (e_r - 1.0)) * tand;
+  alpha_d_e = (20.0 * M_PI / log(10.0)) * (f / C0) * (e_r / sqrt(e_r_eff_e_0)) * ((e_r_eff_e_0 - 1.0) / (e_r - 1.0)) * tand;
+  alpha_d_o = (20.0 * M_PI / log(10.0)) * (f / C0) * (e_r / sqrt(e_r_eff_o_0)) * ((e_r_eff_o_0 - 1.0) / (e_r - 1.0)) * tand;
 
   c_ms->atten_dielectric_e = alpha_d_e * c_ms->l;
   c_ms->atten_dielectric_o = alpha_d_o * c_ms->l;
 }
 
 
-/* c_microstrip_attenuation() - compute attenuation of coupled microstrips */
+/**
+ * c_microstrip_attenuation() - compute attenuation of coupled microstrips 
+ * @c_ms: coupled microstrips structure pointer
+ *
+ */
 static void c_microstrip_attenuation(c_microstrip * c_ms)
 {
   c_ms->skindepth = skin_depth(c_ms);
@@ -302,7 +627,11 @@ static void c_microstrip_attenuation(c_microstrip * c_ms)
 }
 
 
-/* line_angle() - calculate strips electrical lengths in radians */
+/**
+ * line_angle() - calculate strips electrical lengths in radians 
+ * @c_ms: coupled microstrips structure pointer
+ *
+ */
 static void line_angle(c_microstrip * c_ms)
 {
   gfloat f, l, e_r_eff_e, e_r_eff_o;
@@ -314,9 +643,9 @@ static void line_angle(c_microstrip * c_ms)
   e_r_eff_o = c_ms->er_eff_o;
 
   /* even-mode velocity */
-  v_e = C / sqrt(e_r_eff_e);
+  v_e = C0 / sqrt(e_r_eff_e);
   /* odd-mode velocity */
-  v_o = C / sqrt(e_r_eff_o);
+  v_o = C0 / sqrt(e_r_eff_o);
   /* even-mode wavelength */
   lambda_g_e = v_e / f;
   /* odd-mode wavelength */
@@ -351,14 +680,13 @@ void syn_err_fun(double *f1, double *f2, double s_h, double w_h, double e_r, dou
   //g_print("syn_err_fun: f1 = %e\tf2 = %e\n", *f1, *f2);
 }
 
-/*
- * synth_width - calculate widths given Z0 and e_r
- * from Akhtarzad S. et al., "The design of coupled microstrip lines",
- * IEEE Trans. MTT-23, June 1975 and
- * Hinton, J.H., "On design of coupled microstrip lines", IEEE Trans.
- * MTT-28, March 1980
+/**
+ * synth_width() - calculate widths given Z0 and e_r
+ *
+ * References: Akhtarzad S. et al., "The design of coupled microstrip lines", IEEE Trans. MTT-23, June 1975 
+ *
+ * Hinton, J.H., "On design of coupled microstrip lines", IEEE Trans. MTT-28, March 1980
  */
-
 static void synth_width(c_microstrip * c_ms)
 {
   gfloat Z0, Z0e, Z0o, e_r, h;
@@ -427,7 +755,11 @@ static void synth_width(c_microstrip * c_ms)
 }
 
 
-/* Z0_dispersion() - calculate frequency dependency of characteristic impedances */
+/**
+ * Z0_dispersion() - calculate frequency dependency of characteristic impedances 
+ * @c_ms: coupled microstrips structure pointer
+ *
+ */
 static void Z0_dispersion(c_microstrip * c_ms)
 {
   gfloat Q_0;
@@ -509,8 +841,17 @@ static void Z0_dispersion(c_microstrip * c_ms)
 }
 
 
+/**
+ * calc_c_microstrip() - compute characteristics of a coupled microstrip lines structure
+ * @c_ms: coupled microstrips structure pointer
+ *
+ * compute the characteristics of the coupled microstrips structure pointed by @c_ms. 
+ * References: Manfred Kirschning and Rolf Jansen, "Accurate Wide-Range Design Equations for the Frequency-Dependent Characteristic of Parallel Coupled Microstrip Lines", IEEE Trans. MTT, vol. 32, no. 1, Jan. 1984
+ */
 void calc_c_microstrip(c_microstrip * c_ms)
 {
+  /* compute thickness corrections */
+  delta_u_thickness(c_ms);
   /* get effective dielectric constants */
   er_eff_static(c_ms);
   /* impedances for even- and odd-mode */
@@ -527,15 +868,6 @@ void calc_c_microstrip(c_microstrip * c_ms)
   line_angle(c_ms);
 }
 
-/*
- * simple error message
- */
-static void error_mes(gchar * text)
-{
-  perror(text);
-  exit(-1);
-}
-
 
 /*
  * get_microstrip_sub
@@ -872,6 +1204,7 @@ void c_microstrip_win(GtkWidget * parent)
   /* if there is a window that already exists kill it first */
   if (main_body_window != NULL) {
     gtk_widget_destroy(main_body_window);
+    g_free (twin);
     twin = g_malloc(sizeof(*twin));
   }
   setup_transgui(C_MICROSTRIP, parent, twin);
