@@ -22,11 +22,11 @@ USA.
 
 #include <config.h>
 
-#ifdef HAVE_IMLIB
+/* #ifdef HAVE_IMLIB */
 
 #include <stdio.h>
 #include <gtk/gtk.h>
-#include <gdk_imlib.h>
+/* #include <gdk_imlib.h> */
 #include <string.h>
 
 
@@ -34,50 +34,62 @@ void
 pack_image_in_box (GtkWidget *parent, gchar *filename)
 {
   GtkWidget *pixmapwid;
-  GdkPixmap *pixmap;
-  GdkBitmap *mask;
-/*   GtkStyle *style; */
-  GdkImlibImage *image;
-  gint width;
-  gint height;
+
+  /*  GdkPixmap *pixmap;
+      GdkBitmap *mask; */
+
+  /*   GdkImlibImage *image;*/
+  /*  gint width;
+      gint height; */
 
 
 
-  gdk_imlib_init(); 
+  /*   gdk_imlib_init(); */
 
+  pixmapwid = gtk_image_new_from_file (filename);
   /* Get gdk to use imlib's visual and colormap */
+  /*
   gtk_widget_push_visual(gdk_imlib_get_visual());
   gtk_widget_push_colormap(gdk_imlib_get_colormap());
+  */
 
   /* Load the image */
+  /*
   if((image = gdk_imlib_load_image(filename)) == NULL) {
     printf("Image load failed\n");
     exit(-1);
   }
 
+  */
+
   /* get the width and height of the image  */
+  /*
   width = image->rgb_width;
   height = image->rgb_height;
-
+  */
   /* render the image */
+  /*
   if(!gdk_imlib_render(image, width, height)) {
     printf("Image render failed!\n");
     exit(-1);
   }
-
+  */
 
   /* move the pimap and mask out of the structure, then free it */
+  /*
   pixmap = gdk_imlib_move_image(image);
   mask = gdk_imlib_move_mask(image);
   gdk_imlib_destroy_image(image);
 
 
   pixmapwid = gtk_pixmap_new (pixmap, mask); 
+  */
+
   gtk_box_pack_start (GTK_BOX (parent), pixmapwid, FALSE, FALSE, 0); 
   gtk_widget_show (pixmapwid);
 
 
-  gdk_imlib_free_pixmap(pixmap);
+  /*  gdk_imlib_free_pixmap(pixmap);*/
   gtk_widget_show (parent);
 }
-#endif  /*ifdef HAVE_IMLIB*/
+/*#endif */  /*ifdef HAVE_IMLIB*/
