@@ -33,6 +33,15 @@
 #include "unitscombo.h"
 #include "microstrip.h"
 
+/* this is just a quick hack for mingw32 */
+#ifndef HAVE_ATANH
+static double atanh(double x)
+{
+  return (0.5 * log((1.0 + x) / (1.0 - x)));
+}
+#endif
+
+
 /*
  * skin_depth - calculate skin depth
  */
@@ -296,12 +305,12 @@ static gfloat conductor_losses(microstrip * ms)
     K = exp(-1.2 * pow(Z0_h_1 / 377.0, 0.7));
     /* skin resistance */
     R_s = 1.0 / (sigma * delta);
-    
+
     /* correction for surface roughness */
     R_s *= 1.0 + ((2.0 / M_PI) * atan(1.40 * pow((rough / delta), 2.0)));
     /* strip inductive quality factor */
-    Q_c = (M_PI * Z0_h_1 * w * f) / (R_s * C * K);
-    alpha_c = (20.0 * M_PI / log(10.0)) * f * sqrt(e_r_eff_0) / (C * Q_c);
+    Q_c = (M_PI * Z0_h_1 * w * f) / (R_s * C0 * K);
+    alpha_c = (20.0 * M_PI / log(10.0)) * f * sqrt(e_r_eff_0) / (C0 * Q_c);
   } else {
     alpha_c = 0.0;
   }
@@ -321,7 +330,7 @@ static gfloat dielectric_losses(microstrip * ms)
   e_r_eff_0 = ms->er_eff_0;
   tand = ms->tand;
 
-  alpha_d = (20.0 * M_PI / log(10.0)) * (f / C) * (e_r / sqrt(e_r_eff_0)) * ((e_r_eff_0 - 1.0) / (e_r - 1.0)) * tand;
+  alpha_d = (20.0 * M_PI / log(10.0)) * (f / C0) * (e_r / sqrt(e_r_eff_0)) * ((e_r_eff_0 - 1.0) / (e_r - 1.0)) * tand;
 
   return alpha_d;
 }
@@ -349,7 +358,7 @@ static void mur_eff_ms(microstrip * ms)
 
   mureff = (2.0 * mur) / ((1.0 + mur) + ((1.0 - mur) * pow((1.0 + (10.0 * h / w)), -0.5)));
 
-  ms->mur_eff =  mureff;
+  ms->mur_eff = mureff;
 }
 
 
@@ -398,7 +407,7 @@ static void line_angle(microstrip * ms)
   mur_eff = ms->mur_eff;
 
   /* velocity */
-  v = C / sqrt(e_r_eff * mur_eff);
+  v = C0 / sqrt(e_r_eff * mur_eff);
   /* wavelength */
   lambda_g = v / f;
   /* electrical angles */
@@ -422,15 +431,6 @@ void calc_microstrip(microstrip * ms)
   microstrip_attenuation(ms);
 }
 
-/*
- * simple error message
- */
-void error_mes(gchar * text)
-{
-  perror(text);
-  exit(-1);
-}
-
 
 /*
  * get_microstrip_sub
@@ -720,7 +720,7 @@ void synthesize_microstrip(GtkWidget * widget, trans_win * mwin)
     statusint = CONSISTENT;
   } else {
     perror("malloc ms");
-    exit (-1);
+    exit(-1);
   }
 }
 
@@ -737,6 +737,7 @@ void microstrip_win(GtkWidget * parent)
   /* if there is a window that already exists kill it first */
   if (main_body_window != NULL) {
     gtk_widget_destroy(main_body_window);
+    g_free (twin);
     twin = g_malloc(sizeof(*twin));
   }
 
