@@ -29,12 +29,13 @@ USA.
 
 /* callback function for changing the type of transmission line */
 void 
-transtype (gpointer parent)
+transtype (GtkWidget *widget, gpointer parent)
 {
-  gchar *text;
+  const gchar *text;
 
-  if ((text = gtk_entry_get_text (GTK_ENTRY (GTK_COMBO(transtype_combo)->entry))) != 
-NULL)
+  /*  if ((text = gtk_entry_get_text (GTK_ENTRY (GTK_COMBO(transtype_combo)->entry))) != 
+      NULL)*/
+  if ((text = gtk_entry_get_text (GTK_ENTRY (widget))) != NULL)
     {
       if ((strcmp(text,"Microstrip")) == 0) {
 	current_transtype = MICROSTRIP;
@@ -48,9 +49,10 @@ NULL)
       } else if ((strcmp(text,"Coupled Microstrip")) == 0) {
 	current_transtype = C_MICROSTRIP;
 	c_microstrip_win (parent);
-      } else {
+      }/* else {
 	fprintf(stderr, "transtype(): unknown transmission line type!\n");
       }
+       */
     }
 }
 
@@ -61,14 +63,16 @@ NULL)
 short 
 transtype_int ()
 {
-  gchar *text;
+  const gchar *text;
   
   if ((text = gtk_entry_get_text (GTK_ENTRY (GTK_COMBO(transtype_combo)->entry))) != NULL) {
     if ((strcmp(text,"Microstrip")) == 0) return MICROSTRIP;
     if ((strcmp(text,"Rectangular Waveguide")) == 0) return RECTWAVEGUIDE;
     if ((strcmp(text,"Coaxial Line")) == 0) return COAX;
     if ((strcmp(text,"Coupled Microstrip")) == 0) return C_MICROSTRIP;
+    return (-1); /* error */
   }
+  return (-1); /* error */
 }
 
 
@@ -126,9 +130,9 @@ GtkWidget
   gtk_entry_set_editable (GTK_ENTRY (GTK_COMBO (transtype_combo)->entry), FALSE);
 
   /* hook it upto a callback function to sense when a change has occured */
-  gtk_signal_connect_object (GTK_OBJECT (GTK_COMBO (transtype_combo)->entry), 
+  gtk_signal_connect (GTK_OBJECT (GTK_COMBO (transtype_combo)->entry), 
 			     "changed", GTK_SIGNAL_FUNC (transtype),
-			     GTK_OBJECT (vbox));
+			     (gpointer) vbox);
   /*			     GTK_OBJECT (tg->vertbox));*/
 
   /* add the combo box to frame */
@@ -142,7 +146,7 @@ GtkWidget
   gtk_widget_show (vbox);
 
   current_transtype = MICROSTRIP;
-  transtype(tg->vertbox);
+  transtype(GTK_WIDGET (GTK_ENTRY (GTK_COMBO (transtype_combo)->entry)), tg->vertbox);
   /*  transtype(vbox);*/
     /*microstrip_win (tg); */
 
