@@ -31,6 +31,7 @@ USA.
 #include "transcalc.h"
 #include "file_io.h"
 #include "menu.h"
+extern void print_cb (GtkWidget *, gpointer);
 
 void 
 analyzeCB (GtkWidget *parent)
@@ -91,6 +92,7 @@ static GtkItemFactoryEntry menu_items[] = {
   { "/_File",         NULL,         NULL, 0, "<Branch>" },
   { "/File/_Load", "<control>L", file_dialog, TC_FILE_LOAD, NULL},
   { "/File/_Save", "<control>S", file_dialog, TC_FILE_SAVE, NULL},
+  { "/File/_Print", "<control>P", print_cb, 0, NULL},
   { "/File/sep1", NULL, NULL, 0, "<Separator>"},
   { "/File/_Options", "<control>O", optionsCB, 0, NULL },
   { "/File/sep1", NULL, NULL, 0, "<Separator>"},
