@@ -73,7 +73,7 @@ setup_transgui (int ttype, GtkWidget *parent, trans_win *twin)
     return;
   }
 
-#ifdef HAVE_IMLIB
+  /*#ifdef HAVE_IMLIB */
 
   if ((image_dir = (char *) malloc(50*sizeof(char))) == NULL){
     perror("image dir malloc error:");
@@ -85,7 +85,7 @@ setup_transgui (int ttype, GtkWidget *parent, trans_win *twin)
     return;
   }
 
-#endif
+  /*#endif*/
 
   /* Add a vbox and hbox to start the packing */
   main_body_window = gtk_vbox_new (FALSE, 5);
@@ -118,7 +118,7 @@ setup_transgui (int ttype, GtkWidget *parent, trans_win *twin)
 
   /* Grab the filename for drawing */
 
-#ifdef HAVE_IMLIB
+  /*#ifdef HAVE_IMLIB */
   sprintf (image_dir, "%s/transcalc/images/",DATADIR);    
 /*  sprintf(image_dir, "../images/");*/
   if (stat(image_dir, &statbuf)) {
@@ -153,11 +153,13 @@ setup_transgui (int ttype, GtkWidget *parent, trans_win *twin)
     gtk_widget_show (drawingbox);
   }
   free(drawing_filename);
-
+  /*
 #else
   gtk_widget_set_usize (twin->drawing_frame, 300, -1);
 
-#endif  /* ifdef HAVE_IMLIB */
+#endif
+  */
+  /* ifdef HAVE_IMLIB */
 
   gtk_widget_show (twin->drawing_frame);
 
