@@ -38,6 +38,17 @@ extern gint trc_file_load (FILE *, short);
 
 char version[] = "transcalc " VERSION;
 
+
+/*
+ * simple error message
+ */
+void error_mes(gchar * text)
+{
+  perror(text);
+  exit(-1);
+}
+
+
 void
 usage (void)
 {
@@ -59,16 +70,21 @@ usage (void)
 char *
 get_home_directory (void)
 {
-  struct passwd *current_passwd;
-  uid_t user_id;
-  setpwent ();
-  user_id = getuid ();
-  while ((current_passwd = getpwent ()))
-    {
-      if (current_passwd->pw_uid == user_id)
-        return current_passwd->pw_dir;
-    }
-  return NULL;
+  char *home = getenv ("HOME");
+  
+  if (!home) {
+#ifndef PLATFORM_WIN32
+    /* If HOME is not defined, try getting it from the password
+       file.  */
+    struct passwd *pwd = getpwuid (getuid ());
+    if (!pwd || !pwd->pw_dir)
+      return NULL;
+    home = pwd->pw_dir;
+#else  /* WINDOWS */
+    home = ".";
+#endif /* WINDOWS */
+  }
+  return home;
 }
 
 
@@ -116,7 +132,11 @@ running_for_first_time (void)
   char *config_directory = get_config_directory ();
   char *config_filename = get_config_filename ();
 
+#ifndef PLATFORM_WIN32
   if (mkdir (config_directory, TRC_CONFIG_DIRECTORY_MODE) != 0) { 
+#else
+  if (mkdir (config_directory) != 0) { 
+#endif
     /*config dir already there */
     return;
   } else {
@@ -132,11 +152,13 @@ running_for_first_time (void)
 	perror ("open[config_file]");
 	exit (-1);
       }
+#ifndef PLATFORM_WIN32
     if (fchmod (config_file_fd, TRC_CONFIG_DIRECTORY_MODE) != 0)
         {
           perror ("fchmod[" TRC_CONFIG_FILE "]");
           exit (-1);
         }
+#endif
     close (config_file_fd);
     printf ("[%s] created\n\n", config_filename);
   }
@@ -153,7 +175,7 @@ read_config_file (void)
   gchar tmp_str1[80];
   char *config_filename = get_config_filename ();
 
-  if (stat(config_filename, &config_file_stat) != 0){
+  if (stat(config_filename, &config_file_stat) == 0){
     if (config_file_stat.st_size > 0) { /*not empty file */
       fp = fopen(config_filename, "r");
       do { 
@@ -170,10 +192,10 @@ read_config_file (void)
       /* make sure it terminates with '\0' */
       *end = '\0';
       
-      sscanf(ip,"%s %d\n",tmp_str1,&freq_unit);
-      fscanf(fp,"%s %d\n",tmp_str1,&length_unit);
-      fscanf(fp, "%s %d\n",tmp_str1,&res_unit);
-      fscanf(fp, "%s %d\n",tmp_str1,&ang_unit);      
+      sscanf(ip,"%s %hd\n",tmp_str1,&freq_unit);
+      fscanf(fp,"%s %hd\n",tmp_str1,&length_unit);
+      fscanf(fp, "%s %hd\n",tmp_str1,&res_unit);
+      fscanf(fp, "%s %hd\n",tmp_str1,&ang_unit);      
     }
   }
 }
@@ -273,8 +295,7 @@ main( int   argc,
   
   /* setup the main area of calculations */
   tgui->body = setup_body (tgui);
-  
-  
+
   /* setup the status field at the botttom */
   /*  status = GTK_WIDGET (setup_status (tgui)); 
       statusexists = TRUE; */
@@ -282,6 +303,7 @@ main( int   argc,
   gtk_widget_show (tgui->vertbox);
   gtk_widget_show (tgui->mainwindow);
 
+
   fpinit = fopen(save_filename, "r");
   g_free (save_filename);
   if (fpinit != NULL) {
@@ -290,7 +312,6 @@ main( int   argc,
 				 main_window_width, main_window_height);
   }
   
-  
   /* All GTK applications must have a gtk_main(). Control ends here
    * and waits for an event to occur (like a key press or
    * mouse event). */
