@@ -1,6 +1,7 @@
 /*
 
 Copyright (C) 2001  Gopal Narayanan <gopal@astro.umass.edu>
+Copyright (C) 2002 Claudio Girardi <claudio.girardi@ieee.org>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -33,7 +34,11 @@ USA.
 #include <sys/stat.h>
 #include <unistd.h>
 #include <string.h>
+
+#ifdef HAVE_PWD_H /* on mingw32 there is no pwd.h */
 #include <pwd.h>
+#endif
+
 #include <math.h>
 #include <gtk/gtk.h>
 #include "units.h"
@@ -72,9 +77,19 @@ GtkWidget *transtype_combo;
 #define M_PI           3.14159265358979323846  /* pi */
 #endif
 
+/*
+ * The foolwing constant values are from
+ *   The NIST Reference on Constants, Units and Uncertainty
+ * 
+ *   CODATA Recommended Values of the Fundamental Physical Constants: 1998 
+ *     Peter J. Mohr and Barry N. Taylor
+ *     National Institute of standards and Technology, Gaithersburg, MD 20899-8401
+ *
+ * available at http://physics.nist.gov/constants
+ */
 #define MU0 (4*M_PI*1e-7)       /* permeability */
-#define ER0 (8.854e-12)         /* permittivity */
-#define C (2.997956377e8)                /* speed of light m/s*/
+#define ER0 (8.854187817e-12)   /* permittivity */
+#define C0 (299792458)          /* speed of light m/s*/
 
 #define CONSISTENT 0             /* status of fields in calculation */
 #define INCONSISTENT 1
@@ -155,6 +170,8 @@ trans_gui *tgui;
 gboolean statusexists;
 int main_window_width, main_window_height;
 
+void error_mes(gchar * text);
+
 extern gint delete_event (GtkWidget *, GdkEvent *, gpointer);
 extern void destroy (GtkWidget *, gpointer);
 /*extern GtkWidget *setup_body (GtkWidget *);*/
