@@ -31,6 +31,8 @@ USA.
 #include <math.h>
 
 #include "transcalc.h"
+#include "body.h"
+
 
 gchar *length_unit_name[] = { "mil",
 			      "cm",
@@ -186,11 +188,11 @@ setup_combo_widget (short type, short rownum)
 {
 /*   GList *glist = NULL; */
   GtkWidget *combo;
-  short trans_type;
+  /*  short trans_type;*/
 
-  trans_type = transtype_int();
+  /*  trans_type = transtype_int();*/
 
-  switch(trans_type) {
+  switch(current_transtype) {
   case MICROSTRIP :
     switch (type) {
     case SUBPARAMTYPE :
@@ -516,8 +518,8 @@ setup_combo_widget (short type, short rownum)
   default:
     fprintf(stderr, "setup_combo_widget: unknown transmission line type!\n");
   }
-
-
+  /* error */
+  return NULL;
 }
 
 
@@ -546,7 +548,8 @@ getunit (gchar *text)
 
   if ((strcmp(text,"Deg")) == 0) return ANG_DEG;
   if ((strcmp(text,"Rad")) == 0) return ANG_RAD;
-
+  /* error */
+  return (-1);
 }
   
 
@@ -582,5 +585,7 @@ length_unit_text (short unitint)
   default:
     fprintf(stderr, "length_unit_text: unknown unit!\n");
   }
+  /* error */
+  return NULL;
 }    
 
